SeleniumHTMLRunnerResultsHandler (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.htmlrunner
Class SeleniumHTMLRunnerResultsHandler

    java.lang.Object
      org.openqa.selenium.server.htmlrunner.SeleniumHTMLRunnerResultsHandler

All Implemented Interfaces:
  java.io.Serializable, org.mortbay.http.HttpHandler, org.mortbay.util.LifeCycle

    public class SeleniumHTMLRunnerResultsHandler

extends java.lang.Object
implements org.mortbay.http.HttpHandler

Handles results of HTMLRunner (aka TestRunner, FITRunner) in automatic mode.

Author:
  Dan Fabulich, Darren Cotterill, Ajit George
See Also:
  Serialized Form

Constructor Summary
`SeleniumHTMLRunnerResultsHandler()`

Method Summary
`void` | `addListener(HTMLResultsListener listener)`
`org.mortbay.http.HttpContext` | `getHttpContext()`
`java.lang.String` | `getName()`
`void` | `handle(java.lang.String pathInContext, java.lang.String pathParams, org.mortbay.http.HttpRequest request, org.mortbay.http.HttpResponse res)`
`void` | `initialize(org.mortbay.http.HttpContext c)`
`boolean` | `isStarted()`
`void` | `start()`
`void` | `stop()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### SeleniumHTMLRunnerResultsHandler

    public SeleniumHTMLRunnerResultsHandler()

Method Detail

### addListener

    public void addListener(HTMLResultsListener listener)

### handle

    public void handle(java.lang.String pathInContext,
                       java.lang.String pathParams,
                       org.mortbay.http.HttpRequest request,
                       org.mortbay.http.HttpResponse res)
                throws org.mortbay.http.HttpException,
                       java.io.IOException

  Specified by:
    `handle` in interface `org.mortbay.http.HttpHandler`
  Throws:
    `org.mortbay.http.HttpException`
    `java.io.IOException`

### getName

    public java.lang.String getName()

  Specified by:
    `getName` in interface `org.mortbay.http.HttpHandler`

### getHttpContext

    public org.mortbay.http.HttpContext getHttpContext()

  Specified by:
    `getHttpContext` in interface `org.mortbay.http.HttpHandler`

### initialize

    public void initialize(org.mortbay.http.HttpContext c)

  Specified by:
    `initialize` in interface `org.mortbay.http.HttpHandler`

### start

    public void start()
               throws java.lang.Exception

  Specified by:
    `start` in interface `org.mortbay.util.LifeCycle`
  Throws:
    `java.lang.Exception`

### stop

    public void stop()
              throws java.lang.InterruptedException

  Specified by:
    `stop` in interface `org.mortbay.util.LifeCycle`
  Throws:
    `java.lang.InterruptedException`

### isStarted

    public boolean isStarted()

  Specified by:
    `isStarted` in interface `org.mortbay.util.LifeCycle`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.